![PyPI - Version](https://img.shields.io/pypi/v/microscopemetrics)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/microscopemetrics)
![GitHub Workflow Status (with event)](https://img.shields.io/github/actions/workflow/status/MontpellierRessourcesImagerie/microscope-metrics/run_tests_push.yml)
[![GPLv2 License](https://img.shields.io/badge/License-GPL%20v3-yellow.svg)](https://opensource.org/licenses/)

<img alt="Logo" height="150" src="https://raw.githubusercontent.com/MontpellierRessourcesImagerie/microscope-metrics/main/docs/media/microscopemetrics_logo.png" width="150"/>


# microscope-metrics

microscope-metrics is a Python library to control microscope quality based on standardized samples


## Documentation

[Documentation](https://linktodocumentation)


## Related

Here are some related projects

[Awesome README](https://github.com/matiassingers/awesome-readme)


## Installation

If you just want to use microscope-metrics you may just install microscope-metrics with pip

```bash
  pip install microscopemetrics
```

For development we use [poetry](https://python-poetry.org/)

## Usage/Examples

```javascript
import Component from 'my-project'

function App() {
  return <Component />
}
```


## Running Tests

To run tests, use pytest

```bash
  pytest tests
```

